"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseExceptionsFilter = void 0;
const common_1 = require("@nestjs/common");
const mongoose_1 = require("mongoose");
const class_validator_1 = require("class-validator");
const custom_exception_1 = require("../exceptions/custom.exception");
const rest_wrapper_class_1 = require("../models/dtos/wrappers/rest-wrapper.class");
class BaseExceptionsFilter {
    constructor(debug, log) {
        this._debug = false;
        this._log = false;
        this._debug = debug;
        this._log = log;
    }
    catch(exception, host) {
        const context = host.switchToHttp();
        const response = context.getResponse();
        if (this._debug) {
            console.log('BaseExceptionsFilter - name:', exception.constructor.name);
        }
        if (this._log) {
            console.log(exception);
        }
        let handledException = null;
        const { restErrors, statusCode } = this.filterException(exception);
        handledException = new custom_exception_1.HandledException(restErrors, statusCode);
        handledException.send(response);
    }
    filterException(exception) {
        const restErrors = [];
        let statusCode = null;
        try {
            if (exception instanceof custom_exception_1.HandledException) {
                restErrors.push(...exception.getErrors());
                statusCode = exception.getStatus() || common_1.HttpStatus.BAD_REQUEST;
            }
            else if (exception instanceof rest_wrapper_class_1.RESTError) {
                restErrors.push(exception);
                statusCode = exception.statusCode || common_1.HttpStatus.BAD_REQUEST;
            }
            else if (exception instanceof Array) {
                exception.forEach((item) => {
                    restErrors.push(...this.filterException(item).restErrors);
                });
                statusCode = common_1.HttpStatus.BAD_REQUEST;
            }
            else if (exception instanceof common_1.BadRequestException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('bad_request'));
                statusCode = common_1.HttpStatus.BAD_REQUEST;
            }
            else if (exception instanceof common_1.UnauthorizedException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('unauthorized'));
                statusCode = common_1.HttpStatus.UNAUTHORIZED;
            }
            else if (exception instanceof common_1.NotFoundException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('method_not_found', exception.message));
                statusCode = common_1.HttpStatus.METHOD_NOT_ALLOWED;
            }
            else if (exception instanceof common_1.ForbiddenException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('forbidden'));
                statusCode = common_1.HttpStatus.FORBIDDEN;
            }
            else if (exception instanceof common_1.NotAcceptableException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('NotAcceptableException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.RequestTimeoutException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('RequestTimeoutException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.ConflictException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('ConflictException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.GoneException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('GoneException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.HttpVersionNotSupportedException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('HttpVersionNotSupportedException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.PayloadTooLargeException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('PayloadTooLargeException'));
                statusCode = common_1.HttpStatus.PAYLOAD_TOO_LARGE;
            }
            else if (exception instanceof common_1.UnsupportedMediaTypeException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('UnsupportedMediaTypeException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.UnprocessableEntityException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('UnprocessableEntityException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.InternalServerErrorException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('InternalServerErrorException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.NotImplementedException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('NotImplementedException'));
                statusCode = common_1.HttpStatus.NOT_IMPLEMENTED;
            }
            else if (exception instanceof common_1.ImATeapotException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('ImATeapotException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.MethodNotAllowedException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('MethodNotAllowedException'));
                statusCode = common_1.HttpStatus.METHOD_NOT_ALLOWED;
            }
            else if (exception instanceof common_1.BadGatewayException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('BadGatewayException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.ServiceUnavailableException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('ServiceUnavailableException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.GatewayTimeoutException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('GatewayTimeoutException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof common_1.PreconditionFailedException) {
                restErrors.push(new rest_wrapper_class_1.RESTError('PreconditionFailedException'));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof TypeError) {
                restErrors.push(new rest_wrapper_class_1.RESTError('type_error', exception.message));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof mongoose_1.mongo.MongoError) {
                restErrors.push(new rest_wrapper_class_1.RESTError('mongo_error', exception.message));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof class_validator_1.ValidationError) {
                restErrors.push(new rest_wrapper_class_1.RESTError('validation_error', exception));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else if (exception instanceof mongoose_1.mongo.MongoServerError) {
                restErrors.push(new rest_wrapper_class_1.RESTError('mongo_server_error', exception.message));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
            else {
                restErrors.push(new rest_wrapper_class_1.RESTError('unknown_error', exception.message));
                statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
            }
        }
        catch (ex) {
            restErrors.push(new rest_wrapper_class_1.RESTError('base_exception_filter_error', ex));
            statusCode = common_1.HttpStatus.INTERNAL_SERVER_ERROR;
        }
        return { restErrors, statusCode };
    }
}
exports.BaseExceptionsFilter = BaseExceptionsFilter;
//# sourceMappingURL=base-exception.filter.js.map