import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { SessionsService } from './services/sessions.service';
import { MongooseModule } from '@nestjs/mongoose';
import { DL_SESSIONS__MONGO__CS } from './models/consts/env-vars.const';
import { Session, SessionSchema } from './models/schemas/session.schema';
import { HttpModule } from '@nestjs/axios';
import { ISession } from './models/interfaces/session.interface';

declare global {
    namespace Express {
        interface Request {
            session: ISession;
        }
    }
}

@Module({
    imports: [
        ConfigModule,
        HttpModule,
        MongooseModule.forRootAsync({
            connectionName: 'sessions-store',
            useFactory: async (configService: ConfigService) => ({
                uri: configService.get(DL_SESSIONS__MONGO__CS),
            }),
            inject: [ConfigService],
        }),
        MongooseModule.forFeature([{ name: Session.name, schema: SessionSchema }], 'sessions-store'),
    ],
    controllers: [],
    providers: [SessionsService],
    exports: [SessionsService],
})
export class DLCommonsModule {}
